# Code of Conduct
Thank you for your time and help in participating in Sketchingpy project. To ensure that this is a welcoming environment to all, we have a few rules.

<br>

## Inclusive goals
We want this project to offer a welcoming and encouraging home to all that want to participate. We want to be inclusive of everyone in our community in terms of identity, sexuality, race, ethnicity, religion, language, culture, political opinion, age, background, neuro-type, etc. This list is non-exhaustive. All members of the community agree to consider how their contributions will impact others and listen during times of disagreement. 

<br>

## Decision making
Everyone involved in the project wants it to succeed and grow. Sometimes disagreements will emerge and decisions will need to be made by the community to help the project continue forward. We will try our best to reach decisions by consensus. During these conversations, all members of the community agree to:

 - Consider and discuss alternative viewpoints with care, empathy, and open-mindedness.
 - Refrain from attacking conflicting ideas with animosity or engaging in personal attacks against others in the community.
 - In the event that consensus is taking some time to reach, the community agrees to allow those with write access to the repo to set deadlines for conversations / decisions to be made.

In the event that consensus cannot be reached, the community agrees to leave it to the official maintainers with write access on the repo to make the final decision regarding design choices. See `GOVERNANCE.md`.

<br>

## Communication and interaction
The community agrees the following is unacceptable:

 - Statements which are offensive or counter to our goals regarding inclusion.
 - Intimidation or threats of violence.
 - Sexually explicit or violent material including unwelcome sexual attention.
 - Other forms of harassment including stalking and doxing.
 - Use of these tools / software for malicious purpose.

Please remember that this is a broad and public community.

<br>

## Malicious code
Malware, adware, and similar are not acceptable.

<br>

## Potential violations
Violations of the code of conduct may be unintentional. We hope that respectful / kind conversation in the public space can resolve conflict. The goal is always to move forward in the community without exclusion. However, if that is not possible due to repeated violations or severe incidents, the maintainers of this repo may take actions up to and including expulsion from the community. Please reach out to hello@sketchingpy.org if you have concerns.

<br>

## Attribution / CC
This document was inspired by the [p5.js code of conduct](https://github.com/processing/p5.js/blob/main/CODE_OF_CONDUCT.md#p5js-code-of-conduct) and [afscgap code of conduct](https://github.com/SchmidtDSE/afscgap/blob/main/CONDUCT.md) and is released under the [CC BY-SA 4.0 license](https://creativecommons.org/licenses/by-sa/4.0/).